A list of the data within each sheet ($data), and the formatting applied to
each cell ($formats).
Each sheet's data is returned as a data frames, one per sheet, by the sheet
name. For example, the data in a sheet named 'My Worksheet' is in
x$data$My Worksheet. Each data frame has the following
columns:
address The cell address in A1 notation.
row The row number of a cell address (integer).
col The column number of a cell address (integer).
is_blank Whether or not the cell has a value
data_type The type of a cell, referring to the following columns:
error, logical, numeric, date, character, blank.
error The error value of a cell.
logical The boolean value of a cell.
numeric The numeric value of a cell.
date The date value of a cell.
character The string value of a cell.
character_formatted A data frame of substrings and their individual
formatting.
formula The formula in a cell (see 'Details').
is_array Whether or not the formula is an array formula.
formula_ref The address of a range of cells group to which an array
formula or shared formula applies (see 'Details').
formula_group The formula group to which the cell belongs (see
'Details').
comment The text of a comment attached to a cell.
height The height of a cell's row, in Excel's units.
width The width of a cell's column, in Excel's units.
style_format An index into a table of style formats
x$formats$style (see 'Details').
local_format_id An index into a table of local cell formats
x$formats$local (see 'Details').
Strings can be formatted within a cell, so that a single cell can contain
substrings with different formatting. This in-cell formatting is available
in the column character_formatted, which is a list-column of data frames.
Each row of each data frame describes a substring and its formatting. For
cells without a character value, character_formatted is NULL, so for
further processing you might need to filter out the NULLs first.